@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Jekyll
   module LastModifiedAt
     class Tag < Liquid::Tag
@@ -8,11 +10,10 @@ module Jekyll
 
       def render(context)
         site_source = context.registers[:site].source
-        article_file = context.environments.first["page"]["path"]
+        article_file = context.environments.first['page']['path']
 
-        Determinator.new(site_source, article_file, {
-          "format" => @format
-        }).formatted_last_modified_date
+        Determinator.new(site_source, article_file,
+                         'format' => @format).formatted_last_modified_date
       end
     end
   end
